|CI badge| |Release badge|

.. |CI badge| image:: https://github.com/iqm-finland/iqm-client/actions/workflows/ci.yml/badge.svg
.. |Release badge| image:: https://img.shields.io/github/release/iqm-finland/iqm-client.svg

IQM Client
###########

Client-side Python library for connecting to an `IQM <https://meetiqm.com/>`_ quantum computer.

Installation
============

IQM client is not intended to be used directly by human users. For executing code on an IQM quantum computer,
you can use for example the `Cirq on IQM <https://iqm-finland.github.io/cirq-on-iqm/index.html>`_ library.

If you want just this library, though, you can install it from the Python Package Index (PyPI):

.. code-block:: bash

    $ pip install iqm-client


Copyright
=========

IQM client is free software, released under the Apache License, version 2.0.

Copyright 2021-2022 IQM client developers.
